*-- Before you integrate FRX2Any into your VFP application you should realize that FRX2Any
*-- requires GDIPlus.DLL which is freely available and can be installed on Win98 and higher.
*-- If you have not installed WinXP or .NET framework then you can download this DLL from
*-- http://www.microsoft.com/msdownload/platformsdk/sdkupdate/psdkredist.htm
*-- or
*-- http://www.dll-files.com/dllindex/dll-files.shtml?gdiplus


***************************************************************************************************************************
*-- OutPut options
***************************************************************************************************************************
#DEFINE cnOUTPUT_SCREEN			        		 		1
#DEFINE cnOUTPUT_PRINT			         				2
#DEFINE cnOUTPUT_EMAIL			         				3
#DEFINE cnOUTPUT_FILE		 	         				4

***************************************************************************************************************************
*-- IMAGE's output file formats
***************************************************************************************************************************
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_BMP          		1
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_JPG					2
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_GIF					3
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_TIF					4
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_PNG					5

***************************************************************************************************************************
*-- Enumeration type for the various symbol shapes that are available
***************************************************************************************************************************
#DEFINE cnCHART_SYMBOL_TYPE_SQUARE						0
#DEFINE cnCHART_SYMBOL_TYPE_DIAMOND						1
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE					2
#DEFINE cnCHART_SYMBOL_TYPE_CIRCLE						3
#DEFINE cnCHART_SYMBOL_TYPE_XCROSS						4
#DEFINE cnCHART_SYMBOL_TYPE_PLUS						5
#DEFINE cnCHART_SYMBOL_TYPE_STAR						6
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE_DOWN				7

***************************************************************************************************************************
*-- LinearGradient Mode
***************************************************************************************************************************
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_HORIZONTAL			0
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_VERTICAL			1
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL	2
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_BACKWARDDIAGONAL	3


LOCAL laX
LOCAL laY1
LOCAL laY2

LOCAL loFile
LOCAL loChartCurve

LOCAL lcOutPutFileName
LOCAL lcOutPutFilePath

LOCAL lnCount

CD LEFT(SYS(16,0), RAT('\', SYS(16,0)))

lcOutPutFileName = 'DualY'
lcOutPutFilePath = JUSTPATH(SYS(16,0)) + '\OutPut\'

SET PATH TO  ..\..\..\

SET CLASSLIB TO Chart IN FRX2Any.APP ALIAS Chart


loFile = CREATEOBJ('Chart.ChartFile')


IF TYPE('loFile') = 'O'

	WITH loFile

*-- Unlock FRX2Any
		.UNLOCK('xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx')

*-- NOTE: loFile.cExportFileName should not include file extension. For example: loFile.cExportFileName = 'ReportOutput'
		.cExportFileName = lcOutPutFileName

*-- NOTE: loFile.cSaveFolder should contain only path to the output file. For example: loFile.cSaveFolder = 'c:\MyApp\MyOutPut\'
		.cSaveFolder     = lcOutPutFilePath

*-- Specifies that output file will be displayed after creation
		.nOutPutType     = cnOUTPUT_SCREEN

*-- Default value is cnIMAGE_OUTPUT_FILE_FORMAT_GIF
		.nImageFileType  = cnIMAGE_OUTPUT_FILE_FORMAT_JPG


*-- Specify Chart's properties
*-- For description of all Chart's properties and methods, please see FRX2Any help file.

		WITH .oPanel
*-- Set the Title of the Chart
			.cTitle  = 'A simple Line chart with dual Y axes'

			.nWidth  = 800
			.nHeight = 500

*-- Fill the axis background with a gradient
			.oAxisFill.SetGradientFill(RGB(255,255,255), RGB(233,233,233), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL)

			WITH .oXAxis
*-- Set Title of the X Axis
				.cTitle = 'X Axis'

*-- Show the x axis grid
				.lShowGrid = .T.

			ENDWITH

			WITH .oYAxis
*-- Set Title of the Y Axis
				.cTitle = 'Parameter A'

*-- Make the Y axis scale red
				.oScaleFontSpec.nFontColor = RGB(255, 0, 0)
				.oTitleFontSpec.nFontColor = RGB(255, 0, 0)

*-- Turn off the opposite tics so the Y tics don't show up on the Y2 axis
				.lOppositeTic = .F.
				.lMinorOppositeTic = .F.

*-- Don't display the Y zero line
				.lZeroLine = .F.

			ENDWITH


			WITH .oY2Axis
*-- Set Title of the Y Axis
				.cTitle = 'Parameter B'

*-- Enable the Y2 axis display
				.lVisible = .T.

*-- Make the Y2 axis scale blue
				.oScaleFontSpec.nFontColor = RGB(0, 0, 255)
				.oTitleFontSpec.nFontColor = RGB(0, 0, 255)

*-- Turn off the opposite tics so the Y2 tics don't show up on the Y axis
				.lOppositeTic = .F.
				.lMinorOppositeTic = .F.

			ENDWITH

*-- Make up some random data points
			DIMENSION laX[36]
			DIMENSION laY1[36]
			DIMENSION laY2[36]

			FOR lnCount = 1 TO 36

				laX(lnCount)  = (lnCount - 1) * 5
				laY1(lnCount) = SIN((lnCount - 1) * PI() / 15) * 16
				laY2(lnCount) = laY1(lnCount) * 12.5

			NEXT

*-- Generate a red curve with diamond symbols, and 'Volga' in the legend
			loChartCurve = .AddCurve('Alpha', @laX, @laY1, RGB(255, 0, 0), cnCHART_SYMBOL_TYPE_DIAMOND)

*-- Fill the area under the curves
			WITH loChartCurve
				WITH .oSymbol
					WITH .oFill
*-- Create a solid color-fill
						.SetSolidFill(RGB(255, 255, 255))
					ENDWITH
				ENDWITH
			ENDWITH

*-- Generate a blue curve with circle symbols, and 'Nexia' in the legend
			loChartCurve = .AddCurve('Beta', @laX, @laY2, RGB(0, 0, 255), cnCHART_SYMBOL_TYPE_CIRCLE)

*-- Fill the area under the curves
			WITH loChartCurve
				WITH .oSymbol
					WITH .oFill
*-- Create a solid color-fill
						.SetSolidFill(RGB(255, 255, 255))
					ENDWITH
				ENDWITH


*-- Associate this curve with the Y2 axis
				.lY2Axis = .T.


			ENDWITH

		ENDWITH

		.SAVE()

		.RELEASE()

	ENDWITH

ENDIF



