*-- Before you integrate FRX2Any into your VFP application you should realize that FRX2Any
*-- requires GDIPlus.DLL which is freely available and can be installed on Win98 and higher.
*-- If you have not installed WinXP or .NET framework then you can download this DLL from
*-- http://www.microsoft.com/msdownload/platformsdk/sdkupdate/psdkredist.htm
*-- or
*-- http://www.dll-files.com/dllindex/dll-files.shtml?gdiplus


***************************************************************************************************************************
*-- OutPut options
***************************************************************************************************************************
#DEFINE cnOUTPUT_SCREEN			        		 		1
#DEFINE cnOUTPUT_PRINT			         				2
#DEFINE cnOUTPUT_EMAIL			         				3
#DEFINE cnOUTPUT_FILE		 	         				4

***************************************************************************************************************************
*-- IMAGE's output file formats
***************************************************************************************************************************
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_BMP          		1
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_JPG					2
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_GIF					3
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_TIF					4
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_PNG					5

***************************************************************************************************************************
*-- Enumeration type for the various symbol shapes that are available
***************************************************************************************************************************
#DEFINE cnCHART_SYMBOL_TYPE_SQUARE						0
#DEFINE cnCHART_SYMBOL_TYPE_DIAMOND						1
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE					2
#DEFINE cnCHART_SYMBOL_TYPE_CIRCLE						3
#DEFINE cnCHART_SYMBOL_TYPE_XCROSS						4
#DEFINE cnCHART_SYMBOL_TYPE_PLUS						5
#DEFINE cnCHART_SYMBOL_TYPE_STAR						6
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE_DOWN				7

***************************************************************************************************************************
*-- LinearGradient Mode
***************************************************************************************************************************
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_HORIZONTAL			0
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_VERTICAL			1
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL	2
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_BACKWARDDIAGONAL	3

***************************************************************************************************************************
*-- Enumeration type for the various axis types that are available
***************************************************************************************************************************
#DEFINE cnCHART_AXIS_TYPE_LINERAL						0
#DEFINE cnCHART_AXIS_TYPE_LOG							1
#DEFINE cnCHART_AXIS_TYPE_DATE							2
#DEFINE cnCHART_AXIS_TYPE_TEXT							3
#DEFINE cnCHART_AXIS_TYPE_ORDINAL						4

***************************************************************************************************************************
*--	Enumeration type for the various axis date and time unit types that are available
***************************************************************************************************************************
#DEFINE cnCHART_DATE_UNIT_YEAR							0
#DEFINE cnCHART_DATE_UNIT_MONTH							1
#DEFINE cnCHART_DATE_UNIT_DAY							2
#DEFINE cnCHART_DATE_UNIT_HOUR							3
#DEFINE cnCHART_DATE_UNIT_MINUTE						4
#DEFINE cnCHART_DATE_UNIT_SECOND						5



LOCAL laX
LOCAL laHi
LOCAL laLow
LOCAL laClose

LOCAL loFile
LOCAL loChartCurve
LOCAL loErrorBarItem

LOCAL lcOutPutFileName
LOCAL lcOutPutFilePath

LOCAL lnCount
LOCAL lnClose

CD LEFT(SYS(16,0), RAT('\', SYS(16,0)))

lcOutPutFileName = 'HiLowClose'
lcOutPutFilePath = JUSTPATH(SYS(16,0)) + '\OutPut\'

SET PATH TO  ..\..\..\

SET CLASSLIB TO Chart IN FRX2Any.APP ALIAS Chart

loFile = CREATEOBJ('Chart.ChartFile')

IF TYPE('loFile') = 'O'

	WITH loFile

*-- Unlock FRX2Any
		.UNLOCK('xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx')

*-- NOTE: loFile.cExportFileName should not include file extension. For example: loFile.cExportFileName = 'ReportOutput'
		.cExportFileName = lcOutPutFileName

*-- NOTE: loFile.cSaveFolder should contain only path to the output file. For example: loFile.cSaveFolder = 'c:\MyApp\MyOutPut\'
		.cSaveFolder     = lcOutPutFilePath

*-- Specifies that output file will be displayed after creation
		.nOutPutType     = cnOUTPUT_SCREEN

*-- Default value is cnIMAGE_OUTPUT_FILE_FORMAT_GIF
		.nImageFileType  = cnIMAGE_OUTPUT_FILE_FORMAT_JPG


*-- Specify Chart's properties
*-- For description of all Chart's properties and methods, please see FRX2Any help file.

		WITH .oPanel
*-- Set the Title of the Chart
			.cTitle  = 'Hi-Low-Close Daily Stock Chart'

			.nWidth  = 800
			.nHeight = 500

*-- Set the title font characteristics
			.oFontSpec.nSize = 18

*-- Fill the axis background with a gradient
			.oAxisFill.SetGradientFill(RGB(255,255,255), RGB(233,233,233), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL)

*-- Make up some random data points

*-- Initialize the starting close price
			lnClose = 45

			DIMENSION laX[20]
			DIMENSION laHi[20]
			DIMENSION laLow[20]
			DIMENSION laClose[20]


			FOR lnCount = 1 TO 20

*-- Calculate an XL Date from the specified Calendar date (year, month, day)
				laX(lnCount) = .oXAxis.oXDate.CalendarDateToXLDate(2004, 12, lnCount + 15)

				lnClose = lnClose + 2.0 * RAND() - 0.5

				laHi(lnCount) 	 = lnClose + 2.0 * RAND()
				laLow(lnCount)	 = lnClose - 2.0 * RAND()
				laClose(lnCount) = lnClose

			NEXT

			WITH .oXAxis
*-- Set Title of the X Axis
				.cTitle = ''

*-- Set the XAxis to date type
				.nType = cnCHART_AXIS_TYPE_DATE

*-- X axis step size is 1 day
				.nStep = 1
				.nMajorUnit = cnCHART_DATE_UNIT_DAY

*-- Tilt the x axis labels to an angle of 65 degrees
				WITH .oScaleFontSpec
					.nAngle = 65
					.lBold  = .T.
					.nSize  = 12
				ENDWITH

				.cScaleFormat = '&d-&mmm'

			ENDWITH

			WITH .oYAxis
*-- Set Title of the Y Axis
				.cTitle = 'Trading Price, $US'

*-- Display the Y axis grid
				.lShowGrid = .T.
				
			ENDWITH

*-- Make a new curve with a "Closing Price" label
			loChartCurve = .AddCurve('Closing Price', @laX, @laClose, RGB(0, 0, 0), cnCHART_SYMBOL_TYPE_DIAMOND)

			WITH loChartCurve
*-- Turn off the line display, symbols only
				.oLine.lVisible = .F.
*-- Fill the symbols with solid red color
				.oSymbol.oFill.SetSolidFill(RGB(255, 0, 0))
				.oSymbol.nSize = 7
			ENDWITH

*-- Add a blue error bar to the graph
			loErrorBarItem  = .AddErrorBar('Price Range', @laX, @laHi, @laLow, RGB(0, 0, 255))

			WITH loErrorBarItem
				.oErrorBar.nPenWidth = 3
			ENDWITH


		ENDWITH

		.SAVE()

		.RELEASE()

	ENDWITH

ENDIF



