LPARAMETERS tcDocumentName, tnOutPutFileType

*-- Before you integrate FRX2Any into your VFP application you should realize that FRX2Any
*-- requires GDIPlus.DLL which is freely available and can be installed on Win98 and higher.
*-- If you have not installed WinXP or .NET framework then you can download this DLL from
*-- http://www.microsoft.com/downloads/release.asp?releaseid=32738
*-- or
*-- http://www.dll-files.com/dllindex/dll-files.shtml?gdiplus


*-- DO DocumentGeneration WITH 'Customer list', 2

*-- tcDocumentName	 : Output File name without extention
*-- tnOutPutFileType : cnHTML, cnRTF, cnEXCEL, cnPDF, cnIMAGE

***************************************************************************************************************************
*-- Export file types
***************************************************************************************************************************
#DEFINE cnHTML               			 		2
#DEFINE cnRTF               			 		3
#DEFINE cnEXCEL               			 		4
#DEFINE cnPDF	               			 	    7
#DEFINE cnIMAGE	               			 	    8

***************************************************************************************************************************
*-- OutPut options
***************************************************************************************************************************
#DEFINE cnOUTPUT_SCREEN			         		1
#DEFINE cnOUTPUT_PRINT			         		2
#DEFINE cnOUTPUT_EMAIL			         		3
#DEFINE cnOUTPUT_FILE		 	         		4

***************************************************************************************************************************
*-- IMAGE's output file formats
***************************************************************************************************************************
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_BMP          1
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_JPG			2
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_GIF			3
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_TIF			4
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_PNG			5

***************************************************************************************************************************
*-- Excel output file formats
***************************************************************************************************************************
#DEFINE cnEXCEL_OUTPUT_FULL_PLAIN				3

***************************************************************************************************************************
*-- Document alignment constants
***************************************************************************************************************************
#DEFINE cnALIGN_LEFT               				0
#DEFINE cnALIGN_RIGHT              				1
#DEFINE cnALIGN_CENTER             				2

#DEFINE cnDONT_WRAP_TEXT               			5
#DEFINE cnWRAP_TEXT             				8

***************************************************************************************************************************
*-- Report line types
***************************************************************************************************************************
#DEFINE cnREPORT_PEN_PATTERN_NONE		  		0
#DEFINE cnREPORT_PEN_PATTERN_DOTTED		  		1
#DEFINE cnREPORT_PEN_PATTERN_DASHED		  		2
#DEFINE cnREPORT_PEN_PATTERN_DASH_DOT	  		3
#DEFINE cnREPORT_PEN_PATTERN_DASH_DOT_DOT 		4
#DEFINE cnREPORT_PEN_PATTERN_NORMAL 	  		8

***************************************************************************************************************************
*-- FRX Image scale types
***************************************************************************************************************************
#DEFINE cnIMAGE_SCALE_CLIP                 		0
#DEFINE cnIMAGE_SCALE_KEEP_SHAPE    			1
#DEFINE cnIMAGE_SCALE_STRETCH       			2

***************************************************************************************************************************
*-- FRX's Page Orientation Constant Group
***************************************************************************************************************************
#DEFINE cnFRX_PAGE_ORIENTATION_PORTRAIT			0
#DEFINE cnFRX_PAGE_ORIENTATION_LANDSCAPE  		1


LOCAL loFile

LOCAL lcOutPutFileName
LOCAL lcOutPutFilePath
LOCAL lcRunProgram
LOCAL lcCustomerName

LOCAL lnOutPutFileType
LOCAL lnLeft
LOCAL lnTop
LOCAL lnTopDelta
LOCAL lnWidth
LOCAL lnHeight
LOCAL lnBackColor
LOCAL lnRecordCounter

LOCAL llPageWasAdded

lnTopDelta       = 25
lnRecordCounter  = 0

lcCustomerName   = ''
lcRunProgram     = SYS(16,0)

CD LEFT(lcRunProgram, RAT('\', lcRunProgram))

lcOutPutFilePath = JUSTPATH(lcRunProgram) + "\OutPut\"
lcOutPutFileName = IIF(EMPTY(tcDocumentName), 'DocumentName', tcDocumentName)
lnOutPutFileType = IIF(VARTYPE(tnOutPutFileType) = 'N' AND INLIST(tnOutPutFileType, cnHTML, cnRTF, cnEXCEL, cnPDF, cnIMAGE), tnOutPutFileType, cnHTML)

SET PATH TO  ..\..\

SET CLASSLIB TO FRX2Any IN FRX2Any.APP ALIAS FRX2Any

DO CASE
	CASE lnOutPutFileType = cnRTF
		loFile = CREATEOBJECT('FRX2Any.RTFFile')

	CASE lnOutPutFileType = cnHTML
		loFile = CREATEOBJECT('FRX2Any.HTMLFile')

	CASE lnOutPutFileType = cnEXCEL
		loFile = CREATEOBJECT('FRX2Any.ExcelFile')

	CASE lnOutPutFileType = cnPDF
		loFile = CREATEOBJECT('FRX2Any.PDFFile')

	CASE lnOutPutFileType = cnIMAGE
		loFile = CREATEOBJECT('FRX2Any.ImageFile')

ENDCASE


IF TYPE('loFile') = 'O'
*-- Unlock FRX2Any
	loFile.UNLOCK('xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx')

*-- NOTE: loFile.cExportFileName should not include file extension. For example: loFile.cExportFileName = "ReportOutput"
	loFile.cExportFileName = lcOutPutFileName

*-- NOTE: loFile.cSaveFolder should contain only path to the output file. For example: loFile.cSaveFolder = "c:\MyApp\MyOutPut\"
	loFile.cSaveFolder     = lcOutPutFilePath

*-- Specifies that output file will be displayed after creation
	loFile.nOutPutType     = cnOUTPUT_SCREEN

	DO CASE
		CASE lnOutPutFileType = cnHTML
*-- Don't embed Image(s) to HTML file
			loFile.lEmbedImage = .F.

		CASE lnOutPutFileType = cnEXCEL
			loFile.nExcelOutPutType = cnEXCEL_OUTPUT_FULL_PLAIN
			loFile.lMultiWorkSheet  = .T.

		CASE lnOutPutFileType = cnIMAGE
*-- Default value is cnIMAGE_OUTPUT_FILE_FORMAT_GIF
			loFile.nImageFileType  = cnIMAGE_OUTPUT_FILE_FORMAT_TIF

	ENDCASE

	loFile.nOrientation = 0

*-- Specif page size in pixels
	loFile.nPhysicalPaperLength = 992
	loFile.nPhysicalPaperWidth  = 816

	loFile.OpenDocument()
	loFile.AddPage()

	llPageWasAdded = .T.

*-- Open table
	IF !USED('ReportContents')
		USE FULLPATH('..\Reports\ReportContents')
	ENDIF

	SET ORDER TO 2
	GO TOP IN ReportContents

	lnLeft   = 60
	lnTop    = 40
	lnWidth  = 200
	lnHeight = 35

	loFile.RenderText('Invoice List', ;
		'Arial Black', ;
		.T., ;
		.F., ;
		.F., ;
		.F., ;
		19, ;
		lnLeft, ;
		lnTop, ;
		lnWidth, ;
		lnHeight, ;
		cnALIGN_LEFT, ;
		0 , ;
		RGB(0, 0, 0), ;
		RGB(255, 255, 255), ;
		cnDONT_WRAP_TEXT)


	lnLeft   = 550
	lnTop    = 40
	lnWidth  = 200
	lnHeight = 40

	loFile.RenderImage(FULLPATH('..\Reports\FRX2Any.JPG'), lnLeft, lnTop, lnWidth, lnHeight, cnIMAGE_SCALE_STRETCH)

	DO WHILE !EOF('ReportContents')

		lnRecordCounter = lnRecordCounter + 1


		IF EMPTY(lcCustomerName) OR lcCustomerName <> ReportContents.Customer

			lcCustomerName = ReportContents.Customer

*-- Add new page
			IF llPageWasAdded
				llPageWasAdded = .F.
			ELSE
				loFile.AddPage()
			ENDIF

*-- Print header
			lnLeft   = 60
			lnTop    = 115
			lnWidth  = 90
			lnHeight = 20

			loFile.RenderText('Invoice No', ;
				'Arial', ;
				.T., ;
				.F., ;
				.F., ;
				.F., ;
				13, ;
				lnLeft, ;
				lnTop, ;
				lnWidth, ;
				lnHeight, ;
				cnALIGN_LEFT, ;
				0 , ;
				RGB(0, 0, 0), ;
				RGB(255, 255, 255), ;
				cnDONT_WRAP_TEXT)


			lnLeft   = 150
			lnWidth  = 70

			loFile.RenderText('Product', ;
				'Arial', ;
				.T., ;
				.F., ;
				.F., ;
				.F., ;
				13, ;
				lnLeft, ;
				lnTop, ;
				lnWidth, ;
				lnHeight, ;
				cnALIGN_LEFT, ;
				0 , ;
				RGB(0, 0, 0), ;
				RGB(255, 255, 255), ;
				cnDONT_WRAP_TEXT)


			lnLeft   = 555
			lnWidth  = 35

			loFile.RenderText('Qty', ;
				'Arial', ;
				.T., ;
				.F., ;
				.F., ;
				.F., ;
				13, ;
				lnLeft, ;
				lnTop, ;
				lnWidth, ;
				lnHeight, ;
				cnALIGN_LEFT, ;
				0 , ;
				RGB(0, 0, 0), ;
				RGB(255, 255, 255), ;
				cnDONT_WRAP_TEXT)


			lnLeft   = 605
			lnWidth  = 80

			loFile.RenderText('Unit Price', ;
				'Arial', ;
				.T., ;
				.F., ;
				.F., ;
				.F., ;
				13, ;
				lnLeft, ;
				lnTop, ;
				lnWidth, ;
				lnHeight, ;
				cnALIGN_LEFT, ;
				0 , ;
				RGB(0, 0, 0), ;
				RGB(255, 255, 255), ;
				cnDONT_WRAP_TEXT)


			lnLeft   = 695
			lnWidth  = 80

			loFile.RenderText('Total', ;
				'Arial', ;
				.T., ;
				.F., ;
				.F., ;
				.F., ;
				13, ;
				lnLeft, ;
				lnTop, ;
				lnWidth, ;
				lnHeight, ;
				cnALIGN_RIGHT, ;
				0 , ;
				RGB(0, 0, 0), ;
				RGB(255, 255, 255), ;
				cnDONT_WRAP_TEXT)


			lnTop    = 145
			lnLeft   = 60
			lnWidth  = 715
			lnHeight = 0

			loFile.RenderLine(lnLeft, lnTop, lnWidth, lnHeight, 2, 0, cnREPORT_PEN_PATTERN_NORMAL, 1)

			lnTop    = 150
			lnLeft   = 60
			lnWidth  = 105
			lnHeight = 20


			loFile.RenderText('Customer:', ;
				'Arial Black', ;
				.T., ;
				.F., ;
				.F., ;
				.F., ;
				13, ;
				lnLeft, ;
				lnTop, ;
				lnWidth, ;
				lnHeight, ;
				cnALIGN_LEFT, ;
				0 , ;
				RGB(0, 0, 0), ;
				RGB(255, 255, 255), ;
				cnDONT_WRAP_TEXT)


			lnLeft   = 165
			lnWidth  = 300
			lnHeight = 70

			loFile.RenderText(ALLTRIM(ReportContents.Customer), ;
				'Arial Black', ;
				.T., ;
				.F., ;
				.F., ;
				.F., ;
				13, ;
				lnLeft, ;
				lnTop, ;
				lnWidth, ;
				lnHeight, ;
				cnALIGN_LEFT, ;
				0 , ;
				RGB(0, 0, 0), ;
				RGB(255, 255, 255), ;
				cnWRAP_TEXT)


			lnTop  = 205

		ENDIF

		lnBackColor = IIF(MOD(lnRecordCounter, 2) = 0, RGB(192,192,192) , RGB(255, 255, 255))

		lnTop    	= lnTop + lnTopDelta
		lnLeft   	= 60
		lnWidth  	= 80
		lnHeight 	= 20

		loFile.RenderText(ALLTRIM(STR(ReportContents.InvoiceNo)), ;
			'Arial', ;
			.F., ;
			.F., ;
			.F., ;
			.F., ;
			13, ;
			lnLeft, ;
			lnTop, ;
			lnWidth, ;
			lnHeight, ;
			cnALIGN_RIGHT, ;
			0, ;
			0, ;
			lnBackColor, ;
			cnDONT_WRAP_TEXT)


		lnLeft   = 150
		lnWidth  = 400


		loFile.RenderText(ALLTRIM(STRTRAN(ReportContents.PRODUCT, CHR(13) + CHR(10), ' ')), ;
			'Arial', ;
			.F., ;
			.F., ;
			.F., ;
			.F., ;
			13, ;
			lnLeft, ;
			lnTop, ;
			lnWidth, ;
			lnHeight, ;
			cnALIGN_LEFT, ;
			0 , ;
			0, ;
			lnBackColor, ;
			cnDONT_WRAP_TEXT)


		lnLeft   = 555
		lnWidth  = 40

		loFile.RenderText(ALLTRIM(STR(ReportContents.Quantity)), ;
			'Arial', ;
			.F., ;
			.F., ;
			.F., ;
			.F., ;
			13, ;
			lnLeft, ;
			lnTop, ;
			lnWidth, ;
			lnHeight, ;
			cnALIGN_RIGHT, ;
			0 , ;
			0, ;
			lnBackColor, ;
			cnDONT_WRAP_TEXT)



		lnLeft   = 605
		lnWidth  = 80


		loFile.RenderText(ALLTRIM(STR(ReportContents.Price, 7, 2)), ;
			'Arial', ;
			.F., ;
			.F., ;
			.F., ;
			.F., ;
			13, ;
			lnLeft, ;
			lnTop, ;
			lnWidth, ;
			lnHeight, ;
			cnALIGN_RIGHT, ;
			0 , ;
			0, ;
			lnBackColor, ;
			cnDONT_WRAP_TEXT)


		lnLeft   = 695
		lnWidth  = 80


		loFile.RenderText(ALLTRIM(STR(ReportContents.Price * ReportContents.Quantity, 9, 2)), ;
			'Arial', ;
			.F., ;
			.F., ;
			.F., ;
			.F., ;
			13, ;
			lnLeft, ;
			lnTop, ;
			lnWidth, ;
			lnHeight, ;
			cnALIGN_RIGHT, ;
			0 , ;
			0, ;
			lnBackColor, ;
			cnDONT_WRAP_TEXT)

		SKIP
	ENDDO

	loFile.CloseDocument()

	loFile.OutputTo()

ENDIF




